/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.examples;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBox;
import javax.swing.JFrame;
import javax.swing.JPanel;

import net.sf.xcf.MethodNotFoundException;
import net.sf.xcf.RemoteServer;
import net.sf.xcf.UserException;
import net.sf.xcf.XcfManager;
import net.sf.xcf.event.XcfEvent;
import net.sf.xcf.event.system.SystemEventAdapter;
import net.sf.xcf.event.system.AdditionEvent;
import net.sf.xcf.transport.XOPData;
import net.sf.xcf.xml.SyntaxException;

import org.apache.log4j.BasicConfigurator;

import de.unibi.airobots.bonsai.xcf.ConnectionErrorResistantRemoteServer;
import de.unibi.airobots.bonsai.xcf.RemoteServerReconnectableManager;

public class SensorFusionRemote extends JPanel implements ActionListener {

    private JCheckBox c;
    private RemoteServer rSrv;

    public SensorFusionRemote() {
        //super("MultiSensorFusion-Remote");
        //this.setLayout(new BorderLayout());
        BasicConfigurator.configure();

        try {
            // create remote server
            // get registered sensors
            String serverName = "MultiSensorFusion";
            final XcfManager manager = XcfManager.createXcfManager();
            manager.addListener(new SystemEventAdapter() {

                @Override
                public void handleEvent(AdditionEvent e) {
                    //if (e.getUri().equalsIgnoreCase(
                    //        "MSFServer")) {
                        synchronized (manager) {
                            manager.notifyAll();
                        }
                        //System.out.println(e.getData().getDocumentAsText());
                    //}
                }
            });
            try {
                System.out.println("Waiting for ExampleServer...");
                synchronized (manager) {
                    manager.wait();
                }
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            rSrv = manager.createRemoteServer("MSFServer");
            XOPData input = new XOPData();
            XOPData result;
            input
                    .setDocument("<?xml version=\"1.0\"?><XCF val=\"Hello World\"/>");
            XOPData res;
            res = rSrv.callMethod("getSensors", input);
            if (res != null) {
                // TODO fix getServerName
                // System.out.println("Server with name "+ rSrv.getServerName()
                // +
                // " is alive and we received the following response: ");
                System.out.println("Response is: " + res.getDocumentAsText());
                for (int i = 0; i < res.getDocument().getChild(0).getChildCount(); i+=2) {
                    String name = res.getDocument().getChild(0).getChild(i).getChild(0).getValue();
                    boolean active = res.getDocument().getChild(0).getChild(i).getChild(1).getValue().equals("1");
                    JCheckBox c = new JCheckBox(name);
                    c.setSelected(active);
                    c.setVisible(true);
                    c.setActionCommand(name);
                    c.addActionListener(this);
                    this.add(c);
                    System.out.println("Adding checkbox: " + name + "(" + active + ")");
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        this.setVisible(true);
    }

    @Override
    public void actionPerformed(ActionEvent ev) {
        XOPData in = new XOPData();
        try {
            in.setDocument("<?xml version=\"1.0\"?><SENSOR>" + ev.getActionCommand() + "</SENSOR>");
            rSrv.callMethod("xcfToggleSensor",in);
        } catch (SyntaxException e1) {
            // TODO Auto-generated catch block
            e1.printStackTrace();
        } catch (MethodNotFoundException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (UserException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }
}
