/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.examples;

import net.sf.xcf.RemoteServer;
import net.sf.xcf.UserException;
import net.sf.xcf.XcfManager;
import net.sf.xcf.transport.XOPData;

/**
 * Simple test to see what happens if the connection to a remote server dies.
 * 
 * @author jwienke
 */
public class ServerDisconnectTest {

    /**
     * Main method.
     * 
     * @param args
     *            server name, method to call
     */
    public static void main(String[] args) {

        if (args.length != 2) {
            System.err.println("Required arguments: "
                    + "[server name] [method to call]");
            System.exit(1);
        }

        try {

            XcfManager xcfManager = XcfManager.createXcfManager();

            RemoteServer server = xcfManager.createRemoteServer(args[0]);

            System.out.println("First call to method");
            XOPData data = XOPData.fromString("<test/>");
            try {
                server.callMethod(args[1], data);
            } catch (UserException e) {
                System.out.println("Received " + e.getClass().getSimpleName()
                        + ", but that may be ok for testing.");
                e.printStackTrace();
            }

            System.out.println("--- Called method, "
                    + "now waiting 5 seconds before next call ---");

            // CHECKSTYLE:OFF
            Thread.sleep(5000);
            // CHECKSTYLE:ON

            System.out.println("Second call to method");
            try {
                server.callMethod(args[1], data);
            } catch (UserException e) {
                System.out.println("Received " + e.getClass().getSimpleName()
                        + ", but that may be ok for testing.");
                e.printStackTrace();
            }

            // CHECKSTYLE:OFF
        } catch (Exception e) {
            // CHECKSTYLE:ON
            System.err.println("Unexpected error:");
            e.printStackTrace();
            System.exit(1);
        }

    }

}
