/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.skills;

import de.unibi.airobots.bonsai.skills.control.StateMachineController;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Level;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

/**
 * Starts the state machine.
 * 
 * @author lkettenb
 */
public class SCXMLStarter {

    /**
     * The log.
     */
    private static final Logger LOG = 
            Logger.getLogger(SCXMLStarter.class);
    
    /**
     * Default path to BonSAI configuration files.
     */
    private final String pathToConfig = getClass().getResource(
            "/xml/bonsai_config/").getPath();
    
    /**
     * Default path to task files.
     */
    private final String pathToTask = getClass().getResource(
            "/xml/tasks/").getPath();
    
    /**
     * Default path to logging properties file.
     */
    private final URL pathToLoggingProperties = getClass().getResource(
            "/skillsLogging.properties");
    
    /**
     * Starts the application.
     * 
     * @param args Arguments
     */
    public static void main(String[] args) {
        
        // Set look and feel.
        try {
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        } catch (ClassNotFoundException ex) {
            LOG.error("ClassNotFoundException while setting look and feel: " 
                    + ex.getMessage());
        } catch (InstantiationException ex) {
            LOG.error("InstantiationException while setting look and feel: " 
                    + ex.getMessage());
        } catch (IllegalAccessException ex) {
            LOG.error("IllegalAccessException while setting look and feel: " 
                    + ex.getMessage());
        } catch (UnsupportedLookAndFeelException ex) {
            LOG.error("UnsupportedLookAndFeelException while setting "
                    + "look and feel: " + ex.getMessage());
        }
        
        // Look for logging properties file.
        URL pathToLoggingProperties = new SCXMLStarter().pathToLoggingProperties;
        
        if (pathToLoggingProperties == null) {
            BasicConfigurator.configure();
            LOG.error("Did not find logging properties file.");
        } else {
            PropertyConfigurator.configure(pathToLoggingProperties);
            LOG.debug("Found logging properties file. - " + 
                    pathToLoggingProperties.toString());
        }
        
        // Check arguments and set paths
        String pathToConfig;
        String pathToTask;
        
        if (args.length == 2) {
            pathToConfig = args[0];
            pathToTask = args[1];
        } else {
            pathToConfig = new SCXMLStarter().pathToConfig;
            pathToTask = new SCXMLStarter().pathToTask;
        }
        
        
        StateMachineController stateMachineController = 
                new StateMachineController(pathToConfig, pathToTask);
        
        stateMachineController.initialize();
    }

}
