/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.util.helper;

import de.unibi.airobots.bonsai.actuators.NavigationActuator;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.strategies.NavigationStrategy;
import de.unibi.airobots.bonsai.util.CoordinateSystemConverter;
import de.unibi.airobots.bonsai.util.helper.GoalReachedWaiter.ReachStatus;
import de.unibi.airobots.btl.data.navigation.GlobalPlannerStateChange;
import de.unibi.airobots.btl.data.navigation.NavigationGoalData;
import de.unibi.airobots.btl.data.navigation.NavigationGoalData.GoalType;
import de.unibi.airobots.btl.data.navigation.PositionData;
import de.unibi.airobots.btl.data.navigation.SpeedData;
import de.unibi.airobots.btl.units.AngleUnit;
import de.unibi.airobots.btl.units.LengthUnit;
import de.unibi.airobots.btl.units.SpeedUnit;

import java.io.IOException;
import org.apache.log4j.Logger;

/**
 * Helper methods to navigate.
 * @author unknown
 * @deprecated replaced by {@link NavigationStrategy}
 */
@Deprecated
public class Movements {

	private static final long TIMEOUT = 150000;

	public static Logger logger = Logger.getLogger(Movements.class);

	public static ReachStatus turnAround(Sensor<PositionData> positionSensor,
			Sensor<SpeedData> speedSensor,
			Sensor<GlobalPlannerStateChange> gplanChangeSensor,
			NavigationActuator navigationActuator) throws IOException,
			InterruptedException {

		return turnAroundAndMoveBack(0.0, positionSensor, speedSensor,
				gplanChangeSensor, navigationActuator);

	}

	public static ReachStatus turnAroundAndMoveBack(double meters,
			Sensor<PositionData> positionSensor, Sensor<SpeedData> speedSensor,
			Sensor<GlobalPlannerStateChange> gplanChangeSensor,
			NavigationActuator navigationActuator) throws IOException,
			InterruptedException {

		logger.info("Starting to turn around with moving back " + meters
				+ " meters.");

		NavigationGoalData target = CoordinateSystemConverter
				.polar2NavigationGoalData(positionSensor.readLast(), Math.PI,
						meters,AngleUnit.RADIAN, LengthUnit.METER);
		target.setYawTolerance(Math.PI / 8.0,AngleUnit.RADIAN);
		
		navigationActuator.setGoal(target);

		GoalReachedWaiter waiter = new GoalReachedWaiter(positionSensor,
				speedSensor, gplanChangeSensor, navigationActuator);

		ReachStatus reached = waiter.waitForReachingGoal(target, TIMEOUT);

		logger.info("Turning around finished: reached = " + reached);

		return reached;

	}

	/** This nav goal is always GLOBAL!
	 * @param navigationActuator
	 * @param positionSensor
	 * @param speedSensor
	 * @param gplanChangeSensor
	 * @param target
	 * @return
	 * @throws IOException
	 */
	public static boolean driveToPosition(NavigationActuator navigationActuator,
			Sensor<PositionData> positionSensor, Sensor<SpeedData> speedSensor,
			Sensor<GlobalPlannerStateChange> gplanChangeSensor,
			NavigationGoalData target)
			throws IOException {
	    
	        return driveToPosition(navigationActuator, positionSensor, speedSensor, gplanChangeSensor, target, GoalType.GLOBAL);

	}
	
	public static boolean driveToPosition(NavigationActuator navigationActuator,
            Sensor<PositionData> positionSensor, Sensor<SpeedData> speedSensor,
            Sensor<GlobalPlannerStateChange> gplanChangeSensor,
            NavigationGoalData target, GoalType type)
            throws IOException {
	    
	    logger.debug("start drive to positions");
	    target.setType(type);   
	    
        navigationActuator.setGoal(target);
        
        logger.debug("new goalReachedWaiter");
        GoalReachedWaiter waiter = new GoalReachedWaiter(positionSensor,
                speedSensor, gplanChangeSensor, navigationActuator);

        logger.debug("wait for reaching goal");
        ReachStatus reached = waiter.waitForReachingGoal(target, TIMEOUT);

        logger.debug("Driving with status:" + reached);

        if (reached.equals(ReachStatus.NOT_REACHED_BLOCKED)) {
            
            target.setType(GoalType.LOCAL);
            
            reached = new GoalReachedWaiter(positionSensor, speedSensor,
                    gplanChangeSensor, navigationActuator).waitForReachingGoal(target,
                    TIMEOUT);
        }
        
        if (reached.equals(ReachStatus.REACHED)) {
            return true;
        } else {
            return false;
        }
	    
	}
}
